@@ -33,6 +33,7 @@ G_DEFINE_TYPE(GabbleConnection, gabble_connection, G_TYPE_OBJECT)
 enum
 {
     ALIASES_CHANGED,
+    CAPABILITIES_CHANGED,
     NEW_CHANNEL,
     PRESENCE_UPDATE,
     PROPERTIES_CHANGED,
@@ -51,12 +52,16 @@ struct _GabbleConnectionPrivate
   gboolean dispose_has_run;
 };
 
-#define GABBLE_CONNECTION_GET_PRIVATE(o)     (G_TYPE_INSTANCE_GET_PRIVATE ((o), GABBLE_TYPE_CONNECTION, GabbleConnectionPrivate))
+#define GABBLE_CONNECTION_GET_PRIVATE(obj) \
+    ((GabbleConnectionPrivate *)obj->priv)
 
 static void
-gabble_connection_init (GabbleConnection *obj)
+gabble_connection_init (GabbleConnection *self)
 {
-  GabbleConnectionPrivate *priv = GABBLE_CONNECTION_GET_PRIVATE (obj);
+  GabbleConnectionPrivate *priv = G_TYPE_INSTANCE_GET_PRIVATE (self,
+      GABBLE_TYPE_CONNECTION, GabbleConnectionPrivate);
+
+  self->priv = priv;
 
   /* allocate any data required by the object here */
 }
@@ -80,16 +85,25 @@ gabble_connection_class_init (GabbleConnectionClass *gabble_connection_class)
                   G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
                   0,
                   NULL, NULL,
-                  gabble_connection_marshal_VOID__BOXED,
+                  g_cclosure_marshal_VOID__BOXED,
                   G_TYPE_NONE, 1, (dbus_g_type_get_collection ("GPtrArray", (dbus_g_type_get_struct ("GValueArray", G_TYPE_UINT, G_TYPE_STRING, G_TYPE_INVALID)))));
 
+  signals[CAPABILITIES_CHANGED] =
+    g_signal_new ("capabilities-changed",
+                  G_OBJECT_CLASS_TYPE (gabble_connection_class),
+                  G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
+                  0,
+                  NULL, NULL,
+                  g_cclosure_marshal_VOID__BOXED,
+                  G_TYPE_NONE, 1, (dbus_g_type_get_collection ("GPtrArray", (dbus_g_type_get_struct ("GValueArray", G_TYPE_UINT, G_TYPE_STRING, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_INVALID)))));
+
   signals[NEW_CHANNEL] =
     g_signal_new ("new-channel",
                   G_OBJECT_CLASS_TYPE (gabble_connection_class),
                   G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
                   0,
                   NULL, NULL,
-                  gabble_connection_marshal_VOID__STRING_STRING_INT_INT_BOOLEAN,
+                  gabble_connection_marshal_VOID__STRING_STRING_UINT_UINT_BOOLEAN,
                   G_TYPE_NONE, 5, DBUS_TYPE_G_OBJECT_PATH, G_TYPE_STRING, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_BOOLEAN);
 
   signals[PRESENCE_UPDATE] =
@@ -98,7 +112,7 @@ gabble_connection_class_init (GabbleConnectionClass *gabble_connection_class)
                   G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
                   0,
                   NULL, NULL,
-                  gabble_connection_marshal_VOID__BOXED,
+                  g_cclosure_marshal_VOID__BOXED,
                   G_TYPE_NONE, 1, (dbus_g_type_get_map ("GHashTable", G_TYPE_UINT, (dbus_g_type_get_struct ("GValueArray", G_TYPE_UINT, (dbus_g_type_get_map ("GHashTable", G_TYPE_STRING, (dbus_g_type_get_map ("GHashTable", G_TYPE_STRING, G_TYPE_VALUE)))), G_TYPE_INVALID)))));
 
   signals[PROPERTIES_CHANGED] =
@@ -107,7 +121,7 @@ gabble_connection_class_init (GabbleConnectionClass *gabble_connection_class)
                   G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
                   0,
                   NULL, NULL,
-                  gabble_connection_marshal_VOID__BOXED,
+                  g_cclosure_marshal_VOID__BOXED,
                   G_TYPE_NONE, 1, (dbus_g_type_get_collection ("GPtrArray", (dbus_g_type_get_struct ("GValueArray", G_TYPE_UINT, G_TYPE_VALUE, G_TYPE_INVALID)))));
 
   signals[PROPERTY_FLAGS_CHANGED] =
@@ -116,7 +130,7 @@ gabble_connection_class_init (GabbleConnectionClass *gabble_connection_class)
                   G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
                   0,
                   NULL, NULL,
-                  gabble_connection_marshal_VOID__BOXED,
+                  g_cclosure_marshal_VOID__BOXED,
                   G_TYPE_NONE, 1, (dbus_g_type_get_collection ("GPtrArray", (dbus_g_type_get_struct ("GValueArray", G_TYPE_UINT, G_TYPE_UINT, G_TYPE_INVALID)))));
 
   signals[STATUS_CHANGED] =
@@ -125,7 +139,7 @@ gabble_connection_class_init (GabbleConnectionClass *gabble_connection_class)
                   G_SIGNAL_RUN_LAST | G_SIGNAL_DETAILED,
                   0,
                   NULL, NULL,
-                  gabble_connection_marshal_VOID__INT_INT,
+                  gabble_connection_marshal_VOID__UINT_UINT,
                   G_TYPE_NONE, 2, G_TYPE_UINT, G_TYPE_UINT);
 
   dbus_g_object_type_install_info (G_TYPE_FROM_CLASS (gabble_connection_class), &dbus_glib_gabble_connection_object_info);
@@ -164,16 +178,43 @@ gabble_connection_finalize (GObject *object)
 /**
  * gabble_connection_add_status
  *
- * Implements DBus method AddStatus
+ * Implements D-Bus method AddStatus
  * on interface org.freedesktop.Telepathy.Connection.Interface.Presence
  *
  * @error: Used to return a pointer to a GError detailing any error
- *         that occured, DBus will throw the error only if this
- *         function returns false.
+ *         that occurred, D-Bus will throw the error only if this
+ *         function returns FALSE.
  *
  * Returns: TRUE if successful, FALSE if an error was thrown.
  */
-gboolean gabble_connection_add_status (GabbleConnection *obj, const gchar * status, GHashTable * parms, GError **error)
+gboolean
+gabble_connection_add_status (GabbleConnection *self,
+                              const gchar *status,
+                              GHashTable *parms,
+                              GError **error)
+{
+  return TRUE;
+}
+
+
+/**
+ * gabble_connection_advertise_capabilities
+ *
+ * Implements D-Bus method AdvertiseCapabilities
+ * on interface org.freedesktop.Telepathy.Connection.Interface.Capabilities
+ *
+ * @error: Used to return a pointer to a GError detailing any error
+ *         that occurred, D-Bus will throw the error only if this
+ *         function returns FALSE.
+ *
+ * Returns: TRUE if successful, FALSE if an error was thrown.
+ */
+gboolean
+gabble_connection_advertise_capabilities (GabbleConnection *self,
+                                          const GPtrArray *add,
+                                          const gchar **remove,
+                                          GPtrArray **ret,
+                                          GError **error)
 {
   return TRUE;
 }
@@ -182,16 +223,38 @@ gboolean gabble_connection_add_status (GabbleConnection *obj, const gchar * stat
 /**
  * gabble_connection_clear_status
  *
- * Implements DBus method ClearStatus
+ * Implements D-Bus method ClearStatus
  * on interface org.freedesktop.Telepathy.Connection.Interface.Presence
  *
  * @error: Used to return a pointer to a GError detailing any error
- *         that occured, DBus will throw the error only if this
- *         function returns false.
+ *         that occurred, D-Bus will throw the error only if this
+ *         function returns FALSE.
  *
  * Returns: TRUE if successful, FALSE if an error was thrown.
  */
-gboolean gabble_connection_clear_status (GabbleConnection *obj, GError **error)
+gboolean
+gabble_connection_clear_status (GabbleConnection *self,
+                                GError **error)
+{
+  return TRUE;
+}
+
+
+/**
+ * gabble_connection_connect
+ *
+ * Implements D-Bus method Connect
+ * on interface org.freedesktop.Telepathy.Connection
+ *
+ * @error: Used to return a pointer to a GError detailing any error
+ *         that occurred, D-Bus will throw the error only if this
+ *         function returns FALSE.
+ *
+ * Returns: TRUE if successful, FALSE if an error was thrown.
+ */
+gboolean
+gabble_connection_connect (GabbleConnection *self,
+                           GError **error)
 {
   return TRUE;
 }
@@ -200,16 +263,18 @@ gboolean gabble_connection_clear_status (GabbleConnection *obj, GError **error)
 /**
  * gabble_connection_disconnect
  *
- * Implements DBus method Disconnect
+ * Implements D-Bus method Disconnect
  * on interface org.freedesktop.Telepathy.Connection
  *
  * @error: Used to return a pointer to a GError detailing any error
- *         that occured, DBus will throw the error only if this
- *         function returns false.
+ *         that occurred, D-Bus will throw the error only if this
+ *         function returns FALSE.
  *
  * Returns: TRUE if successful, FALSE if an error was thrown.
  */
-gboolean gabble_connection_disconnect (GabbleConnection *obj, GError **error)
+gboolean
+gabble_connection_disconnect (GabbleConnection *self,
+                              GError **error)
 {
   return TRUE;
 }
@@ -218,16 +283,41 @@ gboolean gabble_connection_disconnect (GabbleConnection *obj, GError **error)
 /**
  * gabble_connection_get_alias_flags
  *
- * Implements DBus method GetAliasFlags
+ * Implements D-Bus method GetAliasFlags
  * on interface org.freedesktop.Telepathy.Connection.Interface.Aliasing
  *
  * @error: Used to return a pointer to a GError detailing any error
- *         that occured, DBus will throw the error only if this
- *         function returns false.
+ *         that occurred, D-Bus will throw the error only if this
+ *         function returns FALSE.
  *
  * Returns: TRUE if successful, FALSE if an error was thrown.
  */
-gboolean gabble_connection_get_alias_flags (GabbleConnection *obj, guint* ret, GError **error)
+gboolean
+gabble_connection_get_alias_flags (GabbleConnection *self,
+                                   guint *ret,
+                                   GError **error)
+{
+  return TRUE;
+}
+
+
+/**
+ * gabble_connection_get_capabilities
+ *
+ * Implements D-Bus method GetCapabilities
+ * on interface org.freedesktop.Telepathy.Connection.Interface.Capabilities
+ *
+ * @error: Used to return a pointer to a GError detailing any error
+ *         that occurred, D-Bus will throw the error only if this
+ *         function returns FALSE.
+ *
+ * Returns: TRUE if successful, FALSE if an error was thrown.
+ */
+gboolean
+gabble_connection_get_capabilities (GabbleConnection *self,
+                                    const GArray *handles,
+                                    GPtrArray **ret,
+                                    GError **error)
 {
   return TRUE;
 }
@@ -236,34 +326,59 @@ gboolean gabble_connection_get_alias_flags (GabbleConnection *obj, guint* ret, G
 /**
  * gabble_connection_get_interfaces
  *
- * Implements DBus method GetInterfaces
+ * Implements D-Bus method GetInterfaces
  * on interface org.freedesktop.Telepathy.Connection
  *
  * @error: Used to return a pointer to a GError detailing any error
- *         that occured, DBus will throw the error only if this
- *         function returns false.
+ *         that occurred, D-Bus will throw the error only if this
+ *         function returns FALSE.
  *
  * Returns: TRUE if successful, FALSE if an error was thrown.
  */
-gboolean gabble_connection_get_interfaces (GabbleConnection *obj, gchar *** ret, GError **error)
+gboolean
+gabble_connection_get_interfaces (GabbleConnection *self,
+                                  gchar ***ret,
+                                  GError **error)
 {
   return TRUE;
 }
 
 
+/**
+ * gabble_connection_get_presence
+ *
+ * Implements D-Bus method GetPresence
+ * on interface org.freedesktop.Telepathy.Connection.Interface.Presence
+ *
+ * @context: The D-Bus invocation context to use to return values
+ *           or throw an error.
+ */
+void
+gabble_connection_get_presence (GabbleConnection *self,
+                                const GArray *contacts,
+                                DBusGMethodInvocation *context)
+{
+  return;
+}
+
+
 /**
  * gabble_connection_get_properties
  *
- * Implements DBus method GetProperties
+ * Implements D-Bus method GetProperties
  * on interface org.freedesktop.Telepathy.Properties
  *
  * @error: Used to return a pointer to a GError detailing any error
- *         that occured, DBus will throw the error only if this
- *         function returns false.
+ *         that occurred, D-Bus will throw the error only if this
+ *         function returns FALSE.
  *
  * Returns: TRUE if successful, FALSE if an error was thrown.
  */
-gboolean gabble_connection_get_properties (GabbleConnection *obj, const GArray * properties, GPtrArray ** ret, GError **error)
+gboolean
+gabble_connection_get_properties (GabbleConnection *self,
+                                  const GArray *properties,
+                                  GPtrArray **ret,
+                                  GError **error)
 {
   return TRUE;
 }
@@ -272,16 +387,19 @@ gboolean gabble_connection_get_properties (GabbleConnection *obj, const GArray *
 /**
  * gabble_connection_get_protocol
  *
- * Implements DBus method GetProtocol
+ * Implements D-Bus method GetProtocol
  * on interface org.freedesktop.Telepathy.Connection
  *
  * @error: Used to return a pointer to a GError detailing any error
- *         that occured, DBus will throw the error only if this
- *         function returns false.
+ *         that occurred, D-Bus will throw the error only if this
+ *         function returns FALSE.
  *
  * Returns: TRUE if successful, FALSE if an error was thrown.
  */
-gboolean gabble_connection_get_protocol (GabbleConnection *obj, gchar ** ret, GError **error)
+gboolean
+gabble_connection_get_protocol (GabbleConnection *self,
+                                gchar **ret,
+                                GError **error)
 {
   return TRUE;
 }
@@ -290,16 +408,19 @@ gboolean gabble_connection_get_protocol (GabbleConnection *obj, gchar ** ret, GE
 /**
  * gabble_connection_get_self_handle
  *
- * Implements DBus method GetSelfHandle
+ * Implements D-Bus method GetSelfHandle
  * on interface org.freedesktop.Telepathy.Connection
  *
  * @error: Used to return a pointer to a GError detailing any error
- *         that occured, DBus will throw the error only if this
- *         function returns false.
+ *         that occurred, D-Bus will throw the error only if this
+ *         function returns FALSE.
  *
  * Returns: TRUE if successful, FALSE if an error was thrown.
  */
-gboolean gabble_connection_get_self_handle (GabbleConnection *obj, guint* ret, GError **error)
+gboolean
+gabble_connection_get_self_handle (GabbleConnection *self,
+                                   guint *ret,
+                                   GError **error)
 {
   return TRUE;
 }
@@ -308,16 +429,19 @@ gboolean gabble_connection_get_self_handle (GabbleConnection *obj, guint* ret, G
 /**
  * gabble_connection_get_status
  *
- * Implements DBus method GetStatus
+ * Implements D-Bus method GetStatus
  * on interface org.freedesktop.Telepathy.Connection
  *
  * @error: Used to return a pointer to a GError detailing any error
- *         that occured, DBus will throw the error only if this
- *         function returns false.
+ *         that occurred, D-Bus will throw the error only if this
+ *         function returns FALSE.
  *
  * Returns: TRUE if successful, FALSE if an error was thrown.
  */
-gboolean gabble_connection_get_status (GabbleConnection *obj, guint* ret, GError **error)
+gboolean
+gabble_connection_get_status (GabbleConnection *self,
+                              guint *ret,
+                              GError **error)
 {
   return TRUE;
 }
@@ -326,67 +450,78 @@ gboolean gabble_connection_get_status (GabbleConnection *obj, guint* ret, GError
 /**
  * gabble_connection_get_statuses
  *
- * Implements DBus method GetStatuses
+ * Implements D-Bus method GetStatuses
  * on interface org.freedesktop.Telepathy.Connection.Interface.Presence
  *
  * @error: Used to return a pointer to a GError detailing any error
- *         that occured, DBus will throw the error only if this
- *         function returns false.
+ *         that occurred, D-Bus will throw the error only if this
+ *         function returns FALSE.
  *
  * Returns: TRUE if successful, FALSE if an error was thrown.
  */
-gboolean gabble_connection_get_statuses (GabbleConnection *obj, GHashTable ** ret, GError **error)
+gboolean
+gabble_connection_get_statuses (GabbleConnection *self,
+                                GHashTable **ret,
+                                GError **error)
 {
   return TRUE;
 }
 
 
 /**
- * gabble_connection_hold_handle
+ * gabble_connection_hold_handles
  *
- * Implements DBus method HoldHandle
+ * Implements D-Bus method HoldHandles
  * on interface org.freedesktop.Telepathy.Connection
  *
- * @context: The DBUS invocation context to use to return values
+ * @context: The D-Bus invocation context to use to return values
  *           or throw an error.
  */
-gboolean gabble_connection_hold_handle (GabbleConnection *obj, guint handle_type, guint handle, DBusGMethodInvocation *context)
+void
+gabble_connection_hold_handles (GabbleConnection *self,
+                                guint handle_type,
+                                const GArray *handles,
+                                DBusGMethodInvocation *context)
 {
-  return TRUE;
+  return;
 }
 
 
 /**
- * gabble_connection_inspect_handle
+ * gabble_connection_inspect_handles
  *
- * Implements DBus method InspectHandle
+ * Implements D-Bus method InspectHandles
  * on interface org.freedesktop.Telepathy.Connection
  *
- * @error: Used to return a pointer to a GError detailing any error
- *         that occured, DBus will throw the error only if this
- *         function returns false.
- *
- * Returns: TRUE if successful, FALSE if an error was thrown.
+ * @context: The D-Bus invocation context to use to return values
+ *           or throw an error.
  */
-gboolean gabble_connection_inspect_handle (GabbleConnection *obj, guint handle_type, guint handle, gchar ** ret, GError **error)
+void
+gabble_connection_inspect_handles (GabbleConnection *self,
+                                   guint handle_type,
+                                   const GArray *handles,
+                                   DBusGMethodInvocation *context)
 {
-  return TRUE;
+  return;
 }
 
 
 /**
  * gabble_connection_list_channels
  *
- * Implements DBus method ListChannels
+ * Implements D-Bus method ListChannels
  * on interface org.freedesktop.Telepathy.Connection
  *
  * @error: Used to return a pointer to a GError detailing any error
- *         that occured, DBus will throw the error only if this
- *         function returns false.
+ *         that occurred, D-Bus will throw the error only if this
+ *         function returns FALSE.
  *
  * Returns: TRUE if successful, FALSE if an error was thrown.
  */
-gboolean gabble_connection_list_channels (GabbleConnection *obj, GPtrArray ** ret, GError **error)
+gboolean
+gabble_connection_list_channels (GabbleConnection *self,
+                                 GPtrArray **ret,
+                                 GError **error)
 {
   return TRUE;
 }
@@ -395,49 +530,59 @@ gboolean gabble_connection_list_channels (GabbleConnection *obj, GPtrArray ** re
 /**
  * gabble_connection_list_properties
  *
- * Implements DBus method ListProperties
+ * Implements D-Bus method ListProperties
  * on interface org.freedesktop.Telepathy.Properties
  *
  * @error: Used to return a pointer to a GError detailing any error
- *         that occured, DBus will throw the error only if this
- *         function returns false.
+ *         that occurred, D-Bus will throw the error only if this
+ *         function returns FALSE.
  *
  * Returns: TRUE if successful, FALSE if an error was thrown.
  */
-gboolean gabble_connection_list_properties (GabbleConnection *obj, GPtrArray ** ret, GError **error)
+gboolean
+gabble_connection_list_properties (GabbleConnection *self,
+                                   GPtrArray **ret,
+                                   GError **error)
 {
   return TRUE;
 }
 
 
 /**
- * gabble_connection_release_handle
+ * gabble_connection_release_handles
  *
- * Implements DBus method ReleaseHandle
+ * Implements D-Bus method ReleaseHandles
  * on interface org.freedesktop.Telepathy.Connection
  *
- * @context: The DBUS invocation context to use to return values
+ * @context: The D-Bus invocation context to use to return values
  *           or throw an error.
  */
-gboolean gabble_connection_release_handle (GabbleConnection *obj, guint handle_type, guint handle, DBusGMethodInvocation *context)
+void
+gabble_connection_release_handles (GabbleConnection *self,
+                                   guint handle_type,
+                                   const GArray *handles,
+                                   DBusGMethodInvocation *context)
 {
-  return TRUE;
+  return;
 }
 
 
 /**
  * gabble_connection_remove_status
  *
- * Implements DBus method RemoveStatus
+ * Implements D-Bus method RemoveStatus
  * on interface org.freedesktop.Telepathy.Connection.Interface.Presence
  *
  * @error: Used to return a pointer to a GError detailing any error
- *         that occured, DBus will throw the error only if this
- *         function returns false.
+ *         that occurred, D-Bus will throw the error only if this
+ *         function returns FALSE.
  *
  * Returns: TRUE if successful, FALSE if an error was thrown.
  */
-gboolean gabble_connection_remove_status (GabbleConnection *obj, const gchar * status, GError **error)
+gboolean
+gabble_connection_remove_status (GabbleConnection *self,
+                                 const gchar *status,
+                                 GError **error)
 {
   return TRUE;
 }
@@ -446,64 +591,77 @@ gboolean gabble_connection_remove_status (GabbleConnection *obj, const gchar * s
 /**
  * gabble_connection_request_aliases
  *
- * Implements DBus method RequestAliases
+ * Implements D-Bus method RequestAliases
  * on interface org.freedesktop.Telepathy.Connection.Interface.Aliasing
  *
- * @error: Used to return a pointer to a GError detailing any error
- *         that occured, DBus will throw the error only if this
- *         function returns false.
- *
- * Returns: TRUE if successful, FALSE if an error was thrown.
+ * @context: The D-Bus invocation context to use to return values
+ *           or throw an error.
  */
-gboolean gabble_connection_request_aliases (GabbleConnection *obj, const GArray * contacts, gchar *** ret, GError **error)
+void
+gabble_connection_request_aliases (GabbleConnection *self,
+                                   const GArray *contacts,
+                                   DBusGMethodInvocation *context)
 {
-  return TRUE;
+  return;
 }
 
 
 /**
  * gabble_connection_request_channel
  *
- * Implements DBus method RequestChannel
+ * Implements D-Bus method RequestChannel
  * on interface org.freedesktop.Telepathy.Connection
  *
- * @context: The DBUS invocation context to use to return values
+ * @context: The D-Bus invocation context to use to return values
  *           or throw an error.
  */
-gboolean gabble_connection_request_channel (GabbleConnection *obj, const gchar * type, guint handle_type, guint handle, gboolean suppress_handler, DBusGMethodInvocation *context)
+void
+gabble_connection_request_channel (GabbleConnection *self,
+                                   const gchar *type,
+                                   guint handle_type,
+                                   guint handle,
+                                   gboolean suppress_handler,
+                                   DBusGMethodInvocation *context)
 {
-  return TRUE;
+  return;
 }
 
 
 /**
- * gabble_connection_request_handle
+ * gabble_connection_request_handles
  *
- * Implements DBus method RequestHandle
+ * Implements D-Bus method RequestHandles
  * on interface org.freedesktop.Telepathy.Connection
  *
- * @context: The DBUS invocation context to use to return values
+ * @context: The D-Bus invocation context to use to return values
  *           or throw an error.
  */
-gboolean gabble_connection_request_handle (GabbleConnection *obj, guint handle_type, const gchar * name, DBusGMethodInvocation *context)
+void
+gabble_connection_request_handles (GabbleConnection *self,
+                                   guint handle_type,
+                                   const gchar **names,
+                                   DBusGMethodInvocation *context)
 {
-  return TRUE;
+  return;
 }
 
 
 /**
  * gabble_connection_request_presence
  *
- * Implements DBus method RequestPresence
+ * Implements D-Bus method RequestPresence
  * on interface org.freedesktop.Telepathy.Connection.Interface.Presence
  *
  * @error: Used to return a pointer to a GError detailing any error
- *         that occured, DBus will throw the error only if this
- *         function returns false.
+ *         that occurred, D-Bus will throw the error only if this
+ *         function returns FALSE.
  *
  * Returns: TRUE if successful, FALSE if an error was thrown.
  */
-gboolean gabble_connection_request_presence (GabbleConnection *obj, const GArray * contacts, GError **error)
+gboolean
+gabble_connection_request_presence (GabbleConnection *self,
+                                    const GArray *contacts,
+                                    GError **error)
 {
   return TRUE;
 }
@@ -512,16 +670,19 @@ gboolean gabble_connection_request_presence (GabbleConnection *obj, const GArray
 /**
  * gabble_connection_set_aliases
  *
- * Implements DBus method SetAliases
+ * Implements D-Bus method SetAliases
  * on interface org.freedesktop.Telepathy.Connection.Interface.Aliasing
  *
  * @error: Used to return a pointer to a GError detailing any error
- *         that occured, DBus will throw the error only if this
- *         function returns false.
+ *         that occurred, D-Bus will throw the error only if this
+ *         function returns FALSE.
  *
  * Returns: TRUE if successful, FALSE if an error was thrown.
  */
-gboolean gabble_connection_set_aliases (GabbleConnection *obj, GHashTable * aliases, GError **error)
+gboolean
+gabble_connection_set_aliases (GabbleConnection *self,
+                               GHashTable *aliases,
+                               GError **error)
 {
   return TRUE;
 }
@@ -530,16 +691,19 @@ gboolean gabble_connection_set_aliases (GabbleConnection *obj, GHashTable * alia
 /**
  * gabble_connection_set_last_activity_time
  *
- * Implements DBus method SetLastActivityTime
+ * Implements D-Bus method SetLastActivityTime
  * on interface org.freedesktop.Telepathy.Connection.Interface.Presence
  *
  * @error: Used to return a pointer to a GError detailing any error
- *         that occured, DBus will throw the error only if this
- *         function returns false.
+ *         that occurred, D-Bus will throw the error only if this
+ *         function returns FALSE.
  *
  * Returns: TRUE if successful, FALSE if an error was thrown.
  */
-gboolean gabble_connection_set_last_activity_time (GabbleConnection *obj, guint time, GError **error)
+gboolean
+gabble_connection_set_last_activity_time (GabbleConnection *self,
+                                          guint time,
+                                          GError **error)
 {
   return TRUE;
 }
@@ -548,31 +712,37 @@ gboolean gabble_connection_set_last_activity_time (GabbleConnection *obj, guint
 /**
  * gabble_connection_set_properties
  *
- * Implements DBus method SetProperties
+ * Implements D-Bus method SetProperties
  * on interface org.freedesktop.Telepathy.Properties
  *
- * @context: The DBUS invocation context to use to return values
+ * @context: The D-Bus invocation context to use to return values
  *           or throw an error.
  */
-gboolean gabble_connection_set_properties (GabbleConnection *obj, const GPtrArray * properties, DBusGMethodInvocation *context)
+void
+gabble_connection_set_properties (GabbleConnection *self,
+                                  const GPtrArray *properties,
+                                  DBusGMethodInvocation *context)
 {
-  return TRUE;
+  return;
 }
 
 
 /**
  * gabble_connection_set_status
  *
- * Implements DBus method SetStatus
+ * Implements D-Bus method SetStatus
  * on interface org.freedesktop.Telepathy.Connection.Interface.Presence
  *
  * @error: Used to return a pointer to a GError detailing any error
- *         that occured, DBus will throw the error only if this
- *         function returns false.
+ *         that occurred, D-Bus will throw the error only if this
+ *         function returns FALSE.
  *
  * Returns: TRUE if successful, FALSE if an error was thrown.
  */
-gboolean gabble_connection_set_status (GabbleConnection *obj, GHashTable * statuses, GError **error)
+gboolean
+gabble_connection_set_status (GabbleConnection *self,
+                              GHashTable *statuses,
+                              GError **error)
 {
   return TRUE;
 }
