@@ -164,6 +164,7 @@ struct _GabbleParams {
   gchar *alias;
   gchar *auth_mac;
   gchar *auth_btid;
+  gboolean randomize_resource;
 };
 
 enum {
@@ -185,6 +186,7 @@ enum {
     JABBER_PARAM_ALIAS,
     JABBER_PARAM_AUTH_MAC,
     JABBER_PARAM_AUTH_BTID,
+    JABBER_PARAM_RANDOMIZE_RESOURCE,
     LAST_JABBER_PARAM
 };
 
@@ -207,6 +209,7 @@ static const GabbleParamSpec jabber_params[] = {
   { "alias", DBUS_TYPE_STRING_AS_STRING, G_TYPE_STRING, 0, NULL, G_STRUCT_OFFSET(GabbleParams, alias) },
   { "mac", DBUS_TYPE_STRING_AS_STRING, G_TYPE_STRING, 0, NULL, G_STRUCT_OFFSET(GabbleParams, auth_mac) },
   { "btid", DBUS_TYPE_STRING_AS_STRING, G_TYPE_STRING, 0, NULL, G_STRUCT_OFFSET(GabbleParams, auth_btid) },
+  { "randomize-resource", DBUS_TYPE_BOOLEAN_AS_STRING, G_TYPE_BOOLEAN, TP_CONN_MGR_PARAM_FLAG_HAS_DEFAULT, GINT_TO_POINTER(FALSE), G_STRUCT_OFFSET(GabbleParams, randomize_resource) },
   { NULL, NULL, 0, 0, NULL, 0 }
 };
 
@@ -647,6 +650,9 @@ gabble_connection_manager_request_connection (GabbleConnectionManager *self,
                              params.auth_mac);
   SET_PROPERTY_IF_PARAM_SET ("auth-btid", JABBER_PARAM_AUTH_BTID,
                              params.auth_btid);
+  SET_PROPERTY_IF_PARAM_SET ("randomize-resource",
+                              JABBER_PARAM_RANDOMIZE_RESOURCE,
+                              params.randomize_resource);
 
   /* split up account into username, stream-server and resource */
   if (!_gabble_connection_set_properties_from_account (conn, params.account, error))
