@@ -375,6 +375,9 @@ _gabble_roster_channel_add_member_cb (GObject *obj,
   /* subscribe list */
   else if (GABBLE_LIST_HANDLE_SUBSCRIBE == priv->handle)
     {
+      /* add item to the roster (GTalk depends on this, clearing the H flag) */
+      gabble_roster_handle_add (priv->conn->roster, handle, NULL);
+
       /* send <presence type="subscribe"> */
       ret = _gabble_roster_channel_send_presence (GABBLE_ROSTER_CHANNEL (obj),
           LM_MESSAGE_SUB_TYPE_SUBSCRIBE, handle, message, error);
@@ -430,12 +433,11 @@ _gabble_roster_channel_remove_member_cb (GObject *obj,
       if (handle_set_is_member (GABBLE_ROSTER_CHANNEL (obj)->group.local_pending, handle))
         {
           GIntSet *rem = g_intset_new ();
-          GIntSet *empty = g_intset_new();
 
           g_intset_add (rem, handle);
-          gabble_group_mixin_change_members (obj, "", empty, rem, empty, empty, 0, 0);
+          gabble_group_mixin_change_members (obj, "", NULL, rem, NULL, NULL,
+              0, 0);
 
-          g_intset_destroy (empty);
           g_intset_destroy (rem);
         }
     }
