@@ -59,6 +59,7 @@ struct _GabbleGroupMixinPrivate {
     GHashTable *handle_owners;
 };
 
+
 /**
  * gabble_group_mixin_class_get_offset_quark:
  *
@@ -566,13 +567,22 @@ gabble_group_mixin_change_members (GObject *obj,
   GabbleGroupMixin *mixin = GABBLE_GROUP_MIXIN (obj);
   GabbleGroupMixinClass *mixin_cls = GABBLE_GROUP_MIXIN_CLASS (G_OBJECT_GET_CLASS (obj));
   GIntSet *new_add, *new_remove, *new_local_pending,
-          *new_remote_pending, *tmp, *tmp2;
+          *new_remote_pending, *tmp, *tmp2, *empty;
   gboolean ret;
 
-  g_assert (add != NULL);
-  g_assert (remove != NULL);
-  g_assert (local_pending != NULL);
-  g_assert (remote_pending != NULL);
+  empty = g_intset_new ();
+
+  if (add == NULL)
+    add = empty;
+
+  if (remove == NULL)
+    remove = empty;
+
+  if (local_pending == NULL)
+    local_pending = empty;
+
+  if (remote_pending == NULL)
+    remote_pending = empty;
 
   /* members + add */
   new_add = handle_set_update (mixin->members, add);
@@ -701,6 +711,7 @@ gabble_group_mixin_change_members (GObject *obj,
   g_intset_destroy (new_remove);
   g_intset_destroy (new_local_pending);
   g_intset_destroy (new_remote_pending);
+  g_intset_destroy (empty);
 
   return ret;
 }
