@@ -822,7 +822,7 @@ gabble_roster_iq_cb (LmMessageHandler *handler,
               *deny_add, *deny_rem;
       GArray *removed;
       GabbleHandle handle;
-      GabbleRosterChannel *chan;
+      GabbleRosterChannel *pub_chan, *sub_chan, *chan;
       guint i;
 
     case LM_MESSAGE_SUB_TYPE_RESULT:
@@ -849,9 +849,11 @@ gabble_roster_iq_cb (LmMessageHandler *handler,
           deny_rem = NULL;
         }
 
-      /* get the publish channel first because we need it when processing */
-      handle = GABBLE_LIST_HANDLE_PUBLISH;
-      chan = _gabble_roster_get_channel (roster, handle);
+      /* we need these for preserving "fragile" local/remote pending states */
+      pub_chan = _gabble_roster_get_channel (roster,
+          GABBLE_LIST_HANDLE_PUBLISH);
+      sub_chan = _gabble_roster_get_channel (roster,
+          GABBLE_LIST_HANDLE_SUBSCRIBE);
 
       /* iterate every sub-node, which we expect to be <item>s */
       for (item_node = query_node->children;
@@ -907,7 +909,7 @@ gabble_roster_iq_cb (LmMessageHandler *handler,
                * if someone is awaiting our approval - we get this via presence
                * type=subscribe, so we have to not remove them if they're
                * already local_pending in our publish channel */
-              if (!handle_set_is_member (chan->group.local_pending, handle))
+              if (!handle_set_is_member (pub_chan->group.local_pending, handle))
                 {
                   g_intset_add (pub_rem, handle);
                 }
@@ -926,12 +928,23 @@ gabble_roster_iq_cb (LmMessageHandler *handler,
             case GABBLE_ROSTER_SUBSCRIPTION_NONE:
             case GABBLE_ROSTER_SUBSCRIPTION_FROM:
               if (item->ask_subscribe)
-                g_intset_add (sub_rp, handle);
+                {
+                  g_intset_add (sub_rp, handle);
+                }
               else
-                g_intset_add (sub_rem, handle);
+                {
+                  /* don't remove remote pending, presence="unsubscribed" does that */
+                  if (!handle_set_is_member (sub_chan->group.remote_pending, handle))
+                    {
+                      g_intset_add (sub_rem, handle);
+                    }
+                }
               break;
             case GABBLE_ROSTER_SUBSCRIPTION_REMOVE:
-              g_intset_add (sub_rem, handle);
+              if (!handle_set_is_member (sub_chan->group.remote_pending, handle))
+                {
+                  g_intset_add (sub_rem, handle);
+                }
               break;
             default:
               g_assert_not_reached ();
@@ -950,7 +963,10 @@ gabble_roster_iq_cb (LmMessageHandler *handler,
                   g_intset_add (known_add, handle);
               break;
             case GABBLE_ROSTER_SUBSCRIPTION_REMOVE:
-              g_intset_add (known_rem, handle);
+              if (!handle_set_is_member (sub_chan->group.remote_pending, handle))
+                {
+                  g_intset_add (known_rem, handle);
+                }
               break;
             default:
               g_assert_not_reached ();
@@ -984,17 +1000,12 @@ gabble_roster_iq_cb (LmMessageHandler *handler,
             g_array_append_val (removed, handle);
         }
 
-      /* chan was initialised to the publish channel before the for loop */
-
       DEBUG ("calling change members on publish channel");
-      gabble_group_mixin_change_members (G_OBJECT (chan),
+      gabble_group_mixin_change_members (G_OBJECT (pub_chan),
             "", pub_add, pub_rem, NULL, NULL, 0, 0);
 
-      handle = GABBLE_LIST_HANDLE_SUBSCRIBE;
-      chan = _gabble_roster_get_channel (roster, handle);
-
       DEBUG ("calling change members on subscribe channel");
-      gabble_group_mixin_change_members (G_OBJECT (chan),
+      gabble_group_mixin_change_members (G_OBJECT (sub_chan),
             "", sub_add, sub_rem, NULL, sub_rp, 0, 0);
 
       handle = GABBLE_LIST_HANDLE_KNOWN;
