@@ -28,8 +28,14 @@
 #define __GABBLE_UTIL_H__
 
 gboolean g_strdiff (const gchar *left, const gchar *right);
-void lm_message_node_add_nick (LmMessageNode *node, const gchar *nick);
 void lm_message_node_add_own_nick (LmMessageNode *node, GabbleConnection *conn);
 void lm_message_node_steal_children (LmMessageNode *snatcher, LmMessageNode *mum);
+gboolean lm_message_node_has_namespace (LmMessageNode *node, const gchar *ns, const gchar *tag);
+LmMessageNode *lm_message_node_get_child_with_namespace (LmMessageNode *node, const gchar *name, const gchar *ns);
+
+/* format: a@b/c */
+void gabble_decode_jid (const gchar *jid, gchar **a, gchar **b, gchar **c);
+
+gpointer gabble_mixin_offset_cast (gpointer instance, guint offset);
 
 #endif /* __GABBLE_UTIL_H__ */
