@@ -451,7 +451,7 @@ replace_reply_cb (GabbleConnection *conn, LmMessage *sent_msg,
   GabbleVCardManagerRequest *request = (GabbleVCardManagerRequest*) user_data;
   GabbleVCardManager *manager = GABBLE_VCARD_MANAGER (object);
   GabbleVCardManagerPrivate *priv = GABBLE_VCARD_MANAGER_GET_PRIVATE (manager);
-  LmMessageNode *vcard_node;
+  LmMessageNode *vcard_node = NULL;
   GError *err = NULL;
 
   g_assert (request);
@@ -466,8 +466,6 @@ replace_reply_cb (GabbleConnection *conn, LmMessage *sent_msg,
       return LM_HANDLER_RESULT_ALLOW_MORE_HANDLERS;
     }
 
-  vcard_node = lm_message_node_get_child (sent_msg->node, "vCard");
-
   if (lm_message_get_sub_type (reply_msg) == LM_MESSAGE_SUB_TYPE_ERROR)
     {
       LmMessageNode *error_node;
@@ -486,6 +484,10 @@ replace_reply_cb (GabbleConnection *conn, LmMessage *sent_msg,
                              "an unknown error occurred");
         }
     }
+  else
+    {
+      vcard_node = lm_message_node_get_child (sent_msg->node, "vCard");
+    }
 
   DEBUG ("Request %p %s, notifying callback %p", request,
          err ? "failed" : "succeeded", request->callback);
@@ -512,7 +514,7 @@ request_reply_cb (GabbleConnection *conn,
   GabbleVCardManagerRequest *request = (GabbleVCardManagerRequest*) user_data;
   GabbleVCardManager *manager = GABBLE_VCARD_MANAGER (object);
   GabbleVCardManagerPrivate *priv = GABBLE_VCARD_MANAGER_GET_PRIVATE (manager);
-  LmMessageNode *vcard_node;
+  LmMessageNode *vcard_node = NULL;
   GError *err = NULL;
 
   g_assert (request);
@@ -527,7 +529,6 @@ request_reply_cb (GabbleConnection *conn,
       return LM_HANDLER_RESULT_ALLOW_MORE_HANDLERS;
     }
 
-  vcard_node = lm_message_node_get_child (reply_msg->node, "vCard");
 
   if (lm_message_get_sub_type (reply_msg) == LM_MESSAGE_SUB_TYPE_ERROR)
     {
@@ -547,13 +548,20 @@ request_reply_cb (GabbleConnection *conn,
                              "an unknown error occurred");
         }
     }
-  else if (NULL == vcard_node)
-    {
-      err = g_error_new (GABBLE_VCARD_MANAGER_ERROR, GABBLE_VCARD_MANAGER_ERROR_UNKNOWN,
-          "vCard lookup response contained no <vCard> node");
-    }
   else
     {
+      vcard_node = lm_message_node_get_child (reply_msg->node, "vCard");
+
+      if (NULL == vcard_node)
+        {
+          DEBUG ("successful lookup response contained no <vCard> node, "
+              "creating an empty one");
+
+          vcard_node = lm_message_node_add_child (reply_msg->node, "vCard",
+              NULL);
+          lm_message_node_set_attribute (vcard_node, "xmlns", NS_VCARD_TEMP);
+        }
+
       observe_vcard (conn, manager, request->handle, vcard_node);
     }
 
@@ -583,8 +591,9 @@ request_reply_cb (GabbleConnection *conn,
               node = lm_message_node_add_child (vcard_node, key, value);
             }
         }
+
       request_send (request, vcard_node, NULL, &err);
-      
+
       if (err)
         {
           DEBUG ("Request %p failed, notifying callback %p",
@@ -612,6 +621,7 @@ request_reply_cb (GabbleConnection *conn,
                              vcard_node, err, request->user_data);
         }
     }
+
   delete_request (request);
 
   if (err)
